aboutsummaryrefslogtreecommitdiff
path: root/test
diff options
context:
space:
mode:
authorJulian Fleischer <tirednesscankill@warhog.net>2018-08-07 11:50:05 +0200
committerJulian Fleischer <tirednesscankill@warhog.net>2018-08-27 12:23:25 +0200
commit414326952cd6086ebc491413e8cf58a60ad857a4 (patch)
treeb6a5d7c3554d92572512a0067dfa81c556b02f20 /test
parent728c82d029fc477ff3cb2681730ed57809cdc981 (diff)
downloadbitcoin-414326952cd6086ebc491413e8cf58a60ad857a4.tar.xz
use export LC_ALL=C.UTF-8
Diffstat (limited to 'test')
-rwxr-xr-xtest/lint/lint-shell-locale.sh5
1 files changed, 3 insertions, 2 deletions
diff --git a/test/lint/lint-shell-locale.sh b/test/lint/lint-shell-locale.sh
index 242b27c763..efd8081b8c 100755
--- a/test/lint/lint-shell-locale.sh
+++ b/test/lint/lint-shell-locale.sh
@@ -5,7 +5,8 @@
# file COPYING or http://www.opensource.org/licenses/mit-license.php.
#
# Make sure all shell scripts:
# a.) explicitly opt out of locale dependence using "export LC_ALL=C", or
# b.) explicitly opt in to locale dependence using the annotation below.
export LC_ALL=C
@@ -16,7 +17,7 @@ for SHELL_SCRIPT in $(git ls-files -- "*.sh" | grep -vE "src/(secp256k1|univalue
continue
fi
FIRST_NON_COMMENT_LINE=$(grep -vE '^(#.*|)$' "${SHELL_SCRIPT}" | head -1)
- if [[ ${FIRST_NON_COMMENT_LINE} != "export LC_ALL=C" ]]; then
+ if [[ ${FIRST_NON_COMMENT_LINE} != "export LC_ALL=C" && ${FIRST_NON_COMMENT_LINE} != "export LC_ALL=C.UTF-8" ]]; then
echo "Missing \"export LC_ALL=C\" (to avoid locale dependence) as first non-comment non-empty line in ${SHELL_SCRIPT}"
EXIT_CODE=1
fi
@@ -5,7 +5,8 @@
#
# Make sure all shell scripts:
-# a.) explicitly opt out of locale dependence using "export LC_ALL=C", or
+# a.) explicitly opt out of locale dependence using
+# "export LC_ALL=C" or "export LC_ALL=C.UTF-8", or
# b.) explicitly opt in to locale dependence using the annotation below.
export LC_ALL=C